precision mediump float;

varying highp vec2 textureCoordinate;

uniform sampler2D inputImageTexture;
uniform float pointAX;
uniform float pointAY;
uniform float pointBX;
uniform float pointBY;
uniform float radius;
uniform float sampleStrength;
uniform float maxBlur;

const float sampleDist = 0.3;
const int sampleCount = 10;

void main()
{
    float samples[10];
    samples[0] = -0.02;
    samples[1] = -0.01;
    samples[2] =  0.01;
    samples[3] =  0.02;
    samples[4] =  0.03;
    samples[5] =  0.04;
    samples[6] =  0.05;
    samples[7] =  0.06;
    samples[8] =  0.07;
    samples[9] =  0.08;

    vec4 color = texture2D(inputImageTexture, textureCoordinate);

    vec2 dir = vec2(0.5, 0.5) - textureCoordinate;

    vec2 line = vec2(pointBX, pointBY) - vec2(pointAX, pointAY);
    vec2 perpDir = normalize(vec2(line.y, -line.x));

    float dist = abs(dot(perpDir, dir));
    dir = perpDir * dist;

    dist = dist - radius;

    if(dist > 0.0)
    {
        dir = normalize(dir) * clamp(dist * maxBlur * (sampleStrength / 12.0), 1.0, maxBlur);

        vec4 sum = vec4(0,0,0,1.0);

        for (int i = 0; i < sampleCount; i++)
        {
            vec2 coord = clamp(textureCoordinate + dir * -samples[i] * sampleDist, 0.0, 1.0);
            sum += texture2D(inputImageTexture, coord);
        }

        sum *= 1.0 / float(sampleCount);
        float t = dist * sampleStrength;
        t = clamp(t, 0.0, 1.0);

        gl_FragColor = mix(color, sum, t);
    } else {
        gl_FragColor = color;
    }
}