precision mediump float;

varying highp vec2 textureCoordinate;

uniform sampler2D inputImageTexture;
uniform float centerx;
uniform float centery;
uniform float radius;
uniform float sampleStrength;
uniform float maxBlur;

uniform float texW;
uniform float texH;

const float sampleDist = 0.3;
const int sampleCount = 10;

void main()
{
    float textureRatio = texH / texW;

    float samples[10];
    samples[0] = -0.02;
    samples[1] = -0.01;
    samples[2] =  0.01;
    samples[3] =  0.02;
    samples[4] =  0.03;
    samples[5] =  0.04;
    samples[6] =  0.05;
    samples[7] =  0.06;
    samples[8] =  0.07;
    samples[9] =  0.08;

    vec4 color = texture2D(inputImageTexture, textureCoordinate);

    vec2 dir = vec2(centerx, centery) - textureCoordinate;
    dir = (textureRatio > 1.0) ? vec2(dir.x * textureRatio, dir.y) : vec2(dir.x, dir.y * (1.0 / textureRatio));     //circualize
    float dist = sqrt(dir.x * dir.x + dir.y * dir.y) - radius;

    if(dist > 0.0)
    {
        dir = normalize(dir) * clamp(dist * maxBlur * (sampleStrength / 12.0), 1.0, maxBlur);

        vec4 sum = vec4(0, 0, 0, 1.0);

        for (int i = 0; i < sampleCount; i++)
        {
            vec2 coord = clamp(textureCoordinate + dir * -samples[i] * sampleDist, 0.0, 1.0);
            sum += texture2D( inputImageTexture, coord);
        }

        sum *= 1.0 / float(sampleCount);
        float t = dist * sampleStrength;
        t = clamp(t, 0.0, 1.0);

        gl_FragColor = mix(color, sum, t);
    } else {
        gl_FragColor = color;
    }
}